==> duckdb_0.2.4.tar.gz: duckdb/src/duckdb/amalgamation-5.cpp <==
#include "src/optimizer/rule/move_constants.cpp"

#include "src/optimizer/statistics/expression/propagate_aggregate.cpp"

#include "src/optimizer/statistics/expression/propagate_between.cpp"

#include "src/optimizer/statistics/expression/propagate_case.cpp"

#include "src/optimizer/statistics/expression/propagate_cast.cpp"

#include "src/optimizer/statistics/expression/propagate_columnref.cpp"

#include "src/optimizer/statistics/expression/propagate_comparison.cpp"

#include "src/optimizer/statistics/expression/propagate_conjunction.cpp"

#include "src/optimizer/statistics/expression/propagate_constant.cpp"

#include "src/optimizer/statistics/expression/propagate_function.cpp"

#include "src/optimizer/statistics/expression/propagate_operator.cpp"

#include "src/optimizer/statistics/operator/propagate_aggregate.cpp"

#include "src/optimizer/statistics/operator/propagate_cross_product.cpp"

#include "src/optimizer/statistics/operator/propagate_filter.cpp"

#include "src/optimizer/statistics/operator/propagate_get.cpp"

#include "src/optimizer/statistics/operator/propagate_join.cpp"

#include "src/optimizer/statistics/operator/propagate_limit.cpp"

#include "src/optimizer/statistics/operator/propagate_order.cpp"

#include "src/optimizer/statistics/operator/propagate_projection.cpp"

#include "src/optimizer/statistics/operator/propagate_set_operation.cpp"

#include "src/optimizer/statistics/operator/propagate_window.cpp"

#include "src/optimizer/statistics_propagator.cpp"

#include "src/optimizer/topn_optimizer.cpp"

#include "src/parallel/executor.cpp"

#include "src/parallel/pipeline.cpp"

#include "src/parallel/task_scheduler.cpp"

#include "src/parallel/thread_context.cpp"

#include "src/parser/base_expression.cpp"

#include "src/parser/column_definition.cpp"

#include "src/parser/constraint.cpp"

#include "src/parser/constraints/check_constraint.cpp"

#include "src/parser/constraints/not_null_constraint.cpp"

#include "src/parser/constraints/unique_constraint.cpp"

#include "src/parser/expression/case_expression.cpp"

#include "src/parser/expression/cast_expression.cpp"

#include "src/parser/expression/collate_expression.cpp"

#include "src/parser/expression/columnref_expression.cpp"

#include "src/parser/expression/comparison_expression.cpp"

#include "src/parser/expression/conjunction_expression.cpp"

#include "src/parser/expression/constant_expression.cpp"

#include "src/parser/expression/default_expression.cpp"

#include "src/parser/expression/function_expression.cpp"

#include "src/parser/expression/lambda_expression.cpp"

#include "src/parser/expression/operator_expression.cpp"

#include "src/parser/expression/parameter_expression.cpp"

#include "src/parser/expression/star_expression.cpp"

#include "src/parser/expression/subquery_expression.cpp"

#include "src/parser/expression/table_star_expression.cpp"

#include "src/parser/expression/window_expression.cpp"

#include "src/parser/expression_util.cpp"

#include "src/parser/keyword_helper.cpp"

#include "src/parser/parsed_data/alter_table_info.cpp"

#include "src/parser/parsed_data/sample_options.cpp"

#include "src/parser/parsed_expression.cpp"

#include "src/parser/parsed_expression_iterator.cpp"

#include "src/parser/parser.cpp"

#include "src/parser/query_error_context.cpp"

#include "src/parser/query_node.cpp"

#include "src/parser/query_node/recursive_cte_node.cpp"

#include "src/parser/query_node/select_node.cpp"

#include "src/parser/query_node/set_operation_node.cpp"

#include "src/parser/result_modifier.cpp"

#include "src/parser/statement/alter_statement.cpp"

#include "src/parser/statement/call_statement.cpp"

#include "src/parser/statement/copy_statement.cpp"

#include "src/parser/statement/create_statement.cpp"

#include "src/parser/statement/delete_statement.cpp"

#include "src/parser/statement/drop_statement.cpp"

#include "src/parser/statement/execute_statement.cpp"

#include "src/parser/statement/explain_statement.cpp"

#include "src/parser/statement/export_statement.cpp"

#include "src/parser/statement/insert_statement.cpp"

#include "src/parser/statement/pragma_statement.cpp"

#include "src/parser/statement/prepare_statement.cpp"

#include "src/parser/statement/relation_statement.cpp"

#include "src/parser/statement/select_statement.cpp"

#include "src/parser/statement/show_statement.cpp"

#include "src/parser/statement/transaction_statement.cpp"

#include "src/parser/statement/update_statement.cpp"

#include "src/parser/statement/vacuum_statement.cpp"

#include "src/parser/tableref.cpp"

#include "src/parser/tableref/basetableref.cpp"

#include "src/parser/tableref/crossproductref.cpp"

#include "src/parser/tableref/emptytableref.cpp"

#include "src/parser/tableref/expressionlistref.cpp"

#include "src/parser/tableref/joinref.cpp"

#include "src/parser/tableref/subqueryref.cpp"

#include "src/parser/tableref/table_function.cpp"

#include "src/parser/transform/constraint/transform_constraint.cpp"

#include "src/parser/transform/expression/transform_bool_expr.cpp"

#include "src/parser/transform/expression/transform_case.cpp"

#include "src/parser/transform/expression/transform_cast.cpp"

==> duckdb_0.2.5.tar.gz: duckdb/src/duckdb/amalgamation-5.cpp <==
#include "src/optimizer/pushdown/pushdown_set_operation.cpp"

#include "src/optimizer/pushdown/pushdown_single_join.cpp"

#include "src/optimizer/regex_range_filter.cpp"

#include "src/optimizer/remove_unused_columns.cpp"

#include "src/optimizer/rule/arithmetic_simplification.cpp"

#include "src/optimizer/rule/case_simplification.cpp"

#include "src/optimizer/rule/comparison_simplification.cpp"

#include "src/optimizer/rule/conjunction_simplification.cpp"

#include "src/optimizer/rule/constant_folding.cpp"

#include "src/optimizer/rule/date_part_simplification.cpp"

#include "src/optimizer/rule/distributivity.cpp"

#include "src/optimizer/rule/empty_needle_removal.cpp"

#include "src/optimizer/rule/in_clause_simplification_rule.cpp"

#include "src/optimizer/rule/like_optimizations.cpp"

#include "src/optimizer/rule/move_constants.cpp"

#include "src/optimizer/statistics/expression/propagate_aggregate.cpp"

#include "src/optimizer/statistics/expression/propagate_between.cpp"

#include "src/optimizer/statistics/expression/propagate_case.cpp"

#include "src/optimizer/statistics/expression/propagate_cast.cpp"

#include "src/optimizer/statistics/expression/propagate_columnref.cpp"

#include "src/optimizer/statistics/expression/propagate_comparison.cpp"

#include "src/optimizer/statistics/expression/propagate_conjunction.cpp"

#include "src/optimizer/statistics/expression/propagate_constant.cpp"

#include "src/optimizer/statistics/expression/propagate_function.cpp"

#include "src/optimizer/statistics/expression/propagate_operator.cpp"

#include "src/optimizer/statistics/operator/propagate_aggregate.cpp"

#include "src/optimizer/statistics/operator/propagate_cross_product.cpp"

#include "src/optimizer/statistics/operator/propagate_filter.cpp"

#include "src/optimizer/statistics/operator/propagate_get.cpp"

#include "src/optimizer/statistics/operator/propagate_join.cpp"

#include "src/optimizer/statistics/operator/propagate_limit.cpp"

#include "src/optimizer/statistics/operator/propagate_order.cpp"

#include "src/optimizer/statistics/operator/propagate_projection.cpp"

#include "src/optimizer/statistics/operator/propagate_set_operation.cpp"

#include "src/optimizer/statistics/operator/propagate_window.cpp"

#include "src/optimizer/statistics_propagator.cpp"

#include "src/optimizer/topn_optimizer.cpp"

#include "src/parallel/executor.cpp"

#include "src/parallel/pipeline.cpp"

#include "src/parallel/task_scheduler.cpp"

#include "src/parallel/thread_context.cpp"

#include "src/parser/base_expression.cpp"

#include "src/parser/column_definition.cpp"

#include "src/parser/constraint.cpp"

#include "src/parser/constraints/check_constraint.cpp"

#include "src/parser/constraints/not_null_constraint.cpp"

#include "src/parser/constraints/unique_constraint.cpp"

#include "src/parser/expression/case_expression.cpp"

#include "src/parser/expression/cast_expression.cpp"

#include "src/parser/expression/collate_expression.cpp"

#include "src/parser/expression/columnref_expression.cpp"

#include "src/parser/expression/comparison_expression.cpp"

#include "src/parser/expression/conjunction_expression.cpp"

#include "src/parser/expression/constant_expression.cpp"

#include "src/parser/expression/default_expression.cpp"

#include "src/parser/expression/function_expression.cpp"

#include "src/parser/expression/lambda_expression.cpp"

#include "src/parser/expression/operator_expression.cpp"

#include "src/parser/expression/parameter_expression.cpp"

#include "src/parser/expression/star_expression.cpp"

#include "src/parser/expression/subquery_expression.cpp"

#include "src/parser/expression/table_star_expression.cpp"

#include "src/parser/expression/window_expression.cpp"

#include "src/parser/expression_util.cpp"

#include "src/parser/keyword_helper.cpp"

#include "src/parser/parsed_data/alter_table_info.cpp"

#include "src/parser/parsed_data/sample_options.cpp"

#include "src/parser/parsed_expression.cpp"

#include "src/parser/parsed_expression_iterator.cpp"

#include "src/parser/parser.cpp"

#include "src/parser/query_error_context.cpp"

#include "src/parser/query_node.cpp"

#include "src/parser/query_node/recursive_cte_node.cpp"

#include "src/parser/query_node/select_node.cpp"

#include "src/parser/query_node/set_operation_node.cpp"

#include "src/parser/result_modifier.cpp"

#include "src/parser/statement/alter_statement.cpp"

#include "src/parser/statement/call_statement.cpp"

#include "src/parser/statement/copy_statement.cpp"

#include "src/parser/statement/create_statement.cpp"

#include "src/parser/statement/delete_statement.cpp"

#include "src/parser/statement/drop_statement.cpp"

#include "src/parser/statement/execute_statement.cpp"

#include "src/parser/statement/explain_statement.cpp"

#include "src/parser/statement/export_statement.cpp"

#include "src/parser/statement/insert_statement.cpp"

#include "src/parser/statement/pragma_statement.cpp"

#include "src/parser/statement/prepare_statement.cpp"

#include "src/parser/statement/relation_statement.cpp"

#include "src/parser/statement/select_statement.cpp"

#include "src/parser/statement/set_statement.cpp"

#include "src/parser/statement/show_statement.cpp"

#include "src/parser/statement/transaction_statement.cpp"

#include "src/parser/statement/update_statement.cpp"

#include "src/parser/statement/vacuum_statement.cpp"

#include "src/parser/tableref.cpp"

#include "src/parser/tableref/basetableref.cpp"
